Description: fix spelling issues
Author: Sascha Steinbiss <sascha@steinbiss.name> 
Forwarded: https://github.com/genometools/genometools/pull/727, https://github.com/genometools/genometools/pull/762, https://github.com/genometools/genometools/pull/767
Applied-Upstream: 1.5.9, commit:f47cc4a6e13d037d6342b0213a5739031ada59c1
Last-Update: 2016-03-15
--- a/gtdata/doc/fingerprint.lua
+++ b/gtdata/doc/fingerprint.lua
@@ -36,5 +36,5 @@
 
 - 0  everything went fine ('-check': the comparison was successful;
                            '-duplicates': no duplicates found)
-- 1  an error occured     ('-check': the comparison was not successful;
+- 1  an error occurred     ('-check': the comparison was not successful;
                            '-duplicates': duplicates found)]])
--- a/src/core/error_api.h
+++ b/src/core/error_api.h
@@ -26,7 +26,7 @@
    This class is used for the handling of ___user errors___ in __GenomeTools__.
    Thereby, the actual <GtError> object is used to store the __error message__
    while it is signaled by the return value of the called function, if an error
-   occured.
+   occurred.
 
    By convention in __GenomeTools__, the <GtError> object is always passed into
    a function as the last parameter and -1 (or <NULL> for constructors) is used
--- a/src/core/hashtable.h
+++ b/src/core/hashtable.h
@@ -81,14 +81,14 @@
 /**
  * @brief iterate over the hashtable in key order given by compare
  * function <cmp>
- * @return 0 => no error, -1 => error occured
+ * @return 0 => no error, -1 => error occurred
  */
 int          gt_hashtable_foreach_ordered(GtHashtable *ht, Elemvisitfunc iter,
                                           void *data, GtCompare cmp,
                                           GtError *err);
 /**
  * @brief iterate over the hashtable in implementation-defined order
- * @return 0 => no error, -1 => error occured
+ * @return 0 => no error, -1 => error occurred
  */
 int          gt_hashtable_foreach(GtHashtable *ht, Elemvisitfunc iter,
                                   void *data, GtError *err);
--- a/src/core/seq_iterator_api.h
+++ b/src/core/seq_iterator_api.h
@@ -40,7 +40,7 @@
 /* Get next <sequence> (of length <len>) and <description> from <seqit>.
    Note that <seqit> retains ownership of the <sequence> and <description>.
    Returns 1 if another sequence could be parsed, 0 if all given sequence
-   files are exhausted, And -1 if an error occured (<err> is set
+   files are exhausted, And -1 if an error occurred (<err> is set
    accordingly). */
 int             gt_seq_iterator_next(GtSeqIterator *seqit,
                                      const GtUchar **sequence,
--- a/src/extended/node_stream_api.h
+++ b/src/extended/node_stream_api.h
@@ -35,7 +35,7 @@
    If no error occurs, 0 is returned and <genome_node> contains either the next
    <GtGenomeNode> or <NULL>, if the <node_stream> is exhausted.
    If an error occurs, -1 is returned and <err> is set accordingly (the status
-   of <genome_node> is undefined, but no ownership transfer occured). */
+   of <genome_node> is undefined, but no ownership transfer occurred). */
 int           gt_node_stream_next(GtNodeStream *node_stream,
                                   GtGenomeNode **genome_node,
                                   GtError *err);
--- a/src/gth/intermediate.c
+++ b/src/gth/intermediate.c
@@ -515,7 +515,7 @@
     if (XML_Parse(parser, gt_str_get(line), gt_str_length(line), false) ==
         XML_STATUS_ERROR) {
       error = XML_GetErrorCode(parser);
-      gt_error_set(err, "an error occured parsing line "GT_WU
+      gt_error_set(err, "an error occurred parsing line "GT_WU
                    " of file \"%s\": %s",
                    parseinfo.linenumber, outputfilename,
                    XML_ErrorString(error));
@@ -530,7 +530,7 @@
     /* finish parsing */
     if (XML_Parse(parser, NULL, 0, true) == XML_STATUS_ERROR) {
       error = XML_GetErrorCode(parser);
-      gt_error_set(err, "an error occured while finishing the parsing of file "
+      gt_error_set(err, "an error occurred while finishing the parsing of file "
                         "\"%s\": %s", outputfilename, XML_ErrorString(error));
       had_err = -1;
     }
--- a/src/match/eis-encidxseq-construct.h
+++ b/src/match/eis-encidxseq-construct.h
@@ -118,7 +118,7 @@
  * suffix-array data structure to read construction from and progress
  * information
  * @param alphabet encoding to use for the built sequence, "ownership"
- * of alphabet will pass to the returned object if no error occured.
+ * of alphabet will pass to the returned object if no error occurred.
  * @param totalLen length of indexed sequence (including terminator
  * and separators)
  * @param projectName base name of corresponding suffixerator project
--- a/src/match/eis-encidxseq.h
+++ b/src/match/eis-encidxseq.h
@@ -50,7 +50,7 @@
  * pass information that is kept across individual calls
  * @param err genometools error object reference
  * @return number of bits actually written, or (BitOffset)-1 if an
- * error occured
+ * error occurred
  */
 typedef BitOffset (*bitInsertFunc)(BitString cwDest, BitOffset cwOffset,
                                    BitString varDest, BitOffset varOffset,
@@ -436,7 +436,7 @@
  * @param pos position for which to print context
  * @param fp print diagnostics to this file pointer
  * @param hint use this structure for hinting
- * @return 0 if an I/O error occured wrt fp
+ * @return 0 if an I/O error occurred wrt fp
  */
 static inline int
 EISPrintDiagsForPos(const EISeq *seqIdx, GtUword pos, FILE *fp,
--- a/www/genometools.org/htdocs/libgenometools.html
+++ b/www/genometools.org/htdocs/libgenometools.html
@@ -3197,7 +3197,7 @@
    This class is used for the handling of <strong>user errors</strong> in <em>GenomeTools</em>.
    Thereby, the actual <code>GtError</code> object is used to store the <em>error message</em>
    while it is signaled by the return value of the called function, if an error
-   occured.</p><p>   By convention in <em>GenomeTools</em>, the <code>GtError</code> object is always passed into
+   occurred.</p><p>   By convention in <em>GenomeTools</em>, the <code>GtError</code> object is always passed into
    a function as the last parameter and -1 (or <code>NULL</code> for constructors) is used
    as return value to indicate that an error occurred.
    Success is usually indicated by 0 as return value or via a non-<code>NULL</code> object
@@ -5879,7 +5879,7 @@
    If no error occurs, 0 is returned and <code>genome_node</code> contains either the next
    <code>GtGenomeNode</code> or <code>NULL</code>, if the <code>node_stream</code> is exhausted.
    If an error occurs, -1 is returned and <code>err</code> is set accordingly (the status
-   of <code>genome_node</code> is undefined, but no ownership transfer occured).
+   of <code>genome_node</code> is undefined, but no ownership transfer occurred).
 </p>
 <hr>
 <a name="gt_node_stream_pull"></a>
@@ -7430,7 +7430,7 @@
 Get next <code>sequence</code> (of length <code>len</code>) and <code>description</code> from <code>seqit</code>.
    Note that <code>seqit</code> retains ownership of the <code>sequence</code> and <code>description</code>.
    Returns 1 if another sequence could be parsed, 0 if all given sequence
-   files are exhausted, And -1 if an error occured (<code>err</code> is set
+   files are exhausted, And -1 if an error occurred (<code>err</code> is set
    accordingly).
 </p>
 <hr>
--- a/www/genometools.org/htdocs/tools/gt_fingerprint.html
+++ b/www/genometools.org/htdocs/tools/gt_fingerprint.html
@@ -176,7 +176,7 @@
 </li>
 <li>
 <p>
-1  an error occured     (<em>-check</em>: the comparison was not successful;
+1  an error occurred     (<em>-check</em>: the comparison was not successful;
                            <em>-duplicates</em>: duplicates found)
 </p>
 </li>
--- a/src/match/eis-encidxseq.c
+++ b/src/match/eis-encidxseq.c
@@ -50,7 +50,7 @@
   {                                                              \
     switch (retcode) {                                           \
     case EIS_INTEGRITY_CHECK_INVALID_SYMBOL:                     \
-      fprintf(stderr, "Comparision failed at position "GT_WU""   \
+      fprintf(stderr, "Comparison failed at position "GT_WU""   \
               ", reference symbol: %u, symbol read: %u\n",       \
               pos, symOrig, symEnc);                             \
       gt_error_set(err, "Invalid symbol encountered.");          \
--- a/src/tools/gt_compreads_decompress.c
+++ b/src/tools/gt_compreads_decompress.c
@@ -119,7 +119,7 @@
   gt_option_parser_add_option(op, option);
 
   option = gt_option_new_uword("width",
-                               "set width of output, 0 disables formating. "
+                               "set width of output, 0 disables formatting. "
                                "line breaks in quality strings can cause "
                                "problems with parsers, use with care",
                                &arguments->width, 0);
--- a/src/tools/gt_kmer_database.c
+++ b/src/tools/gt_kmer_database.c
@@ -109,7 +109,7 @@
   gt_option_imply(option_use_cutoff, option);
 
   /* -set_cutoff */
-  option = gt_option_new_uword_min("set_cutoff", "kmers occuring more often "
+  option = gt_option_new_uword_min("set_cutoff", "kmers occurring more often "
                                    "than this value won't be saved",
                                    &arguments->cutoff_value, (GtUword) 30,
                                    (GtUword) 1);
--- a/gtdata/doc/extractseq.lua
+++ b/gtdata/doc/extractseq.lua
@@ -46,7 +46,7 @@
 
 If the end of the argument list only contains one filename, say fastaindex, then
 it is checked if there is a file `fastaindex.kys`. This makes up part of the
-fasta index, which is contructed by calling the suffixerator tool as follows:
+fasta index, which is constructed by calling the suffixerator tool as follows:
 
   gt suffixerator -protein -ssp -tis -des -sds -kys -indexname fastaindex \
     -db inputfile1 [inputfile2 ..]
--- a/src/gth/parse_options.c
+++ b/src/gth/parse_options.c
@@ -381,7 +381,7 @@
   gt_option_parser_add_option(op, optverbose);
 
   /* -verboseseqs */
-  optverboseseqs = gt_option_new_bool("verboseseqs", "show additonal sequence "
+  optverboseseqs = gt_option_new_bool("verboseseqs", "show additional sequence "
                                    "information\n(for debugging purposes)",
                                    &call_info->out->verboseseqs, false);
   gt_option_is_development_option(optverboseseqs);
--- a/www/genometools.org/htdocs/tools/gt_extractseq.html
+++ b/www/genometools.org/htdocs/tools/gt_extractseq.html
@@ -211,7 +211,7 @@
 </ul></div>
 <div class="paragraph"><p>If the end of the argument list only contains one filename, say fastaindex, then
 it is checked if there is a file <tt>fastaindex.kys</tt>. This makes up part of the
-fasta index, which is contructed by calling the suffixerator tool as follows:</p></div>
+fasta index, which is constructed by calling the suffixerator tool as follows:</p></div>
 <div class="literalblock">
 <div class="content">
 <pre><tt>gt suffixerator -protein -ssp -tis -des -sds -kys -indexname fastaindex \
--- a/src/extended/affinealign.h
+++ b/src/extended/affinealign.h
@@ -52,7 +52,7 @@
 
 /* Computes a global alignment with affine gapcosts in square space. Use of this
    function requires an initialised <scorehandler> with cost values an
-   initalised <spacemanager>, the target alignment <align> and input sequences
+   initialised <spacemanager>, the target alignment <align> and input sequences
    <useq> and <vseq> and lengths <ulen> and <vlen>. Returns affine cost
    value of global alignment. */
 GtWord gt_affinealign_with_Management(GtLinspaceManagement *spacemanager,
--- a/src/extended/type_node.c
+++ b/src/extended/type_node.c
@@ -109,7 +109,7 @@
 
    That is, if X is_a Y and Z part_of Y, then Z part_of X.
 
-   The method maintains a <node_stack> containing the inital <node> and all
+   The method maintains a <node_stack> containing the initial <node> and all
    its 'is_a' children.
 
    Example from Sequence Ontology (we are looking at mRNA and exon, see
--- a/src/gth/align_protein.c
+++ b/src/gth/align_protein.c
@@ -188,7 +188,7 @@
   return retracenames[retrace];
 }
 
-/* the following function initalizes the input structure */
+/* the following function initializes the input structure */
 static void initinput(GthAlignInputProtein *input,
                       const unsigned char *ref_seq_orig,
                       GthInput *gth_input)
--- a/src/tools/gt_condenseq_compress.c
+++ b/src/tools/gt_condenseq_compress.c
@@ -108,7 +108,7 @@
 
   /* -initsize */
   option = gt_option_new_uword("initsize",
-                               "length of inital unique database in bases, "
+                               "length of initial unique database in bases, "
                                "should be larger than -alignlength",
                                &arguments->initsize, GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, option);
--- a/src/tools/gt_linspace_align.c
+++ b/src/tools/gt_linspace_align.c
@@ -186,7 +186,7 @@
   optionshowscore = gt_option_new_bool("showscore", "show score for alignment, "
                                        "please note it will calculate costs "
                                        "for global alignments and scores for "
-                                       "local alignemnts always, independtly "
+                                       "local alignments always, independently "
                                        "of input ",
                                        &arguments->showscore, false);
   gt_option_parser_add_option(op, optionshowscore);

--- a/src/core/option_api.h
+++ b/src/core/option_api.h
@@ -34,14 +34,14 @@
 
 enum GtOPrval {
   GT_OPTION_PARSER_OK,           /* Everything went fine. */
-  GT_OPTION_PARSER_ERROR,        /* An error occured during option parsing. */
+  GT_OPTION_PARSER_ERROR,        /* An error occurred during option parsing. */
   GT_OPTION_PARSER_REQUESTS_EXIT /* The option parser requests an exit, because
                                     option -help, -help+, -helpdev, or -version
                                     was used. */
 };
 
 /* Possible option parser return values. <GT_OPTION_PARSER_OK> denotes that
-   everything went fine, <GT_OPTION_PARSER_ERROR> that an error occured during
+   everything went fine, <GT_OPTION_PARSER_ERROR> that an error occurred during
    option parsing, and <GT_OPTION_PARSER_REQUESTS_EXIT> that the option parser
    requests an exit, because option <-help>, <-help+>, <-helpdev> or <-version>
    was used. */